/*
 * Copyright  1997 IBM Corporation.
 * Copyright (c) 1997 Sun Microsystems, Inc. All Rights Reserved.
 * Copyright (c) 1997 ORA, Inc. All Rights Reserved.
 * Code derived from  the original OpenCard Framework
 *
 */

import java.io.File;

import opencard.terminal.*;
import opencard.OpenCardConstants;

/** <tt>GetCardID</tt> 
 *
 * @see opencard.terminal.CardTerminal
 * @see opencard.terminal.Slot
 */
public class GetCardID implements OpenCardConstants {
  private static final String GETCARDID_PROPERTY = "GetCardID.";

  public static void main(String[] argv) {
    // ... check usage
    if (argv.length < 1) {
      System.err.println("GetCardID.main() usage: GetCardID terminal-name [slot=#]");
      System.exit(0);
    }
    String ctName = argv[0];
    int slotNumber = 0;
    if (argv.length > 1) 
      slotNumber = Integer.parseInt(argv[1]);

    // ... get a handle on the card terminal registry
    CardTerminalRegistry ctr = CardTerminalRegistry.registry();

    // ... try to obtain the CardID (ATR)
    try {
      // ... retrieve the card terminal
      CardTerminal ct = ctr.cardTerminalForName(ctName);
      Slot slot = ct.slots()[slotNumber];
      
      // ... power the smart card up
      slot.powerUpCard(-1);

      // ... obtain the ATR response
      CardID cid = slot.cardID(-1);
      System.out.println("GetCardID.main() CardID is " + cid);
    } catch (IllegalArgumentException e) {
      System.err.println("GetCardID.main() illegal card terminal name " + ctName);
      e.printStackTrace();
    } catch (CardTerminalException e) {
      System.err.println("GetCardID.main() problem communicating with the smart card, timed out");
      e.printStackTrace();
    } 
  } 
}

